========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/sahara.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

OpenStack Data Processing ("Sahara") project
============================================

Sahara at wiki.openstack.org: https://wiki.openstack.org/wiki/Sahara

Storyboard project: https://storyboard.openstack.org/#!/project/935

Sahara docs site: https://docs.openstack.org/sahara/latest/

Roadmap: https://wiki.openstack.org/wiki/Sahara/Roadmap

Quickstart guide: https://docs.openstack.org/sahara/latest/user/quickstart.html

How to participate: https://docs.openstack.org/sahara/latest/contributor/how-to-participate.html

Source: https://git.openstack.org/cgit/openstack/sahara

Bugs and feature requests: https://storyboard.openstack.org/#!/project/935

Release notes: https://docs.openstack.org/releasenotes/sahara/

License
-------

Apache License Version 2.0 http://www.apache.org/licenses/LICENSE-2.0
